# bl_amazon_api

BlAmazonApi - JavaScript client for bl_amazon_api
This is an API documentation for the Bluehack Amazon Service.
This SDK is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: 0.0.2
- Package version: 0.0.2
- Build package: io.swagger.codegen.languages.JavascriptClientCodegen

## Installation

### For [Node.js](https://nodejs.org/)

#### npm

To publish the library as a [npm](https://www.npmjs.com/),
please follow the procedure in ["Publishing npm packages"](https://docs.npmjs.com/getting-started/publishing-npm-packages).

Then install it via:

```shell
npm install bl_amazon_api --save
```

##### Local development

To use the library locally without publishing to a remote npm registry, first install the dependencies by changing 
into the directory containing `package.json` (and this README). Let's call this `JAVASCRIPT_CLIENT_DIR`. Then run:

```shell
npm install
```

Next, [link](https://docs.npmjs.com/cli/link) it globally in npm with the following, also from `JAVASCRIPT_CLIENT_DIR`:

```shell
npm link
```

Finally, switch to the directory you want to use your bl_amazon_api from, and run:

```shell
npm link /path/to/<JAVASCRIPT_CLIENT_DIR>
```

You should now be able to `require('bl_amazon_api')` in javascript files from the directory you ran the last 
command above from.

#### git
#
If the library is hosted at a git repository, e.g.
https://github.com/YOUR_USERNAME/bl_amazon_api
then install it via:

```shell
    npm install YOUR_USERNAME/bl_amazon_api --save
```

### For browser

The library also works in the browser environment via npm and [browserify](http://browserify.org/). After following
the above steps with Node.js and installing browserify with `npm install -g browserify`,
perform the following (assuming *main.js* is your entry file, that's to say your javascript file where you actually 
use this library):

```shell
browserify main.js > bundle.js
```

Then include *bundle.js* in the HTML pages.

### Webpack Configuration

Using Webpack you may encounter the following error: "Module not found: Error:
Cannot resolve module", most certainly you should disable AMD loader. Add/merge
the following section to your webpack config:

```javascript
module: {
  rules: [
    {
      parser: {
        amd: false
      }
    }
  ]
}
```

## Getting Started

Please follow the [installation](#installation) instruction and execute the following JS code:

```javascript
var BlAmazonApi = require('bl_amazon_api');

var api = new BlAmazonApi.AdvertisingApi()

var nodeId = "nodeId_example"; // {String} 


var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
};
api.getAdvertisingBrowseNode(nodeId, callback);

```

## Documentation for API Endpoints

All URIs are relative to *http://104.198.83.158:80*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*BlAmazonApi.AdvertisingApi* | [**getAdvertisingBrowseNode**](docs/AdvertisingApi.md#getAdvertisingBrowseNode) | **GET** /advertising/browseNodes/{nodeId} | Get browse node hierarchy from Amazon
*BlAmazonApi.AdvertisingApi* | [**getAdvertisingBrowseNodeTopSellers**](docs/AdvertisingApi.md#getAdvertisingBrowseNodeTopSellers) | **GET** /advertising/browseNodes/{nodeId}/topSellers | Get 10 top sellers within a specified browse node from Amazon
*BlAmazonApi.AdvertisingApi* | [**getAdvertisingStatus**](docs/AdvertisingApi.md#getAdvertisingStatus) | **GET** /advertising/status | Get Amazon Product Advertising API status
*BlAmazonApi.MwsApi* | [**getMwsFeedsSubmissions**](docs/MwsApi.md#getMwsFeedsSubmissions) | **GET** /mws/feeds/submissions | Get a list of feed submissions submitted
*BlAmazonApi.MwsApi* | [**getMwsFeedsSubmissionsResult**](docs/MwsApi.md#getMwsFeedsSubmissionsResult) | **GET** /mws/feeds/submissions/{feedSubmissionId}/result | Get the feed processing report
*BlAmazonApi.MwsApi* | [**getMwsStatus**](docs/MwsApi.md#getMwsStatus) | **GET** /mws/status | Get Amazon MWS API status
*BlAmazonApi.MwsApi* | [**postSubmitFeed**](docs/MwsApi.md#postSubmitFeed) | **POST** /mws/feeds/submit | Post feed with a flat file
*BlAmazonApi.ProductApi* | [**getProductsBrowseNodeAttributes**](docs/ProductApi.md#getProductsBrowseNodeAttributes) | **GET** /products/browseNodes/{nodeId}/attributes | Get attributes within a specified browse node for the title generating
*BlAmazonApi.ProductApi* | [**getProductsBrowseNodeValidValue**](docs/ProductApi.md#getProductsBrowseNodeValidValue) | **GET** /products/browseNodes/{nodeId}/validValue | Get the browse node&#39;s valid value for submiting a flat file
*BlAmazonApi.ProductApi* | [**getProductsStatus**](docs/ProductApi.md#getProductsStatus) | **GET** /products/status | Get Product API status
*BlAmazonApi.ToolApi* | [**getDictionaryBrowseNodesAll**](docs/ToolApi.md#getDictionaryBrowseNodesAll) | **GET** /tool/dictionary/browseNodes/{nodeId}/all | Get all dictionary hierarchy within a specified browse node
*BlAmazonApi.ToolApi* | [**getDictionarySubAttrsWords**](docs/ToolApi.md#getDictionarySubAttrsWords) | **GET** /tool/dictionary/subAttrs/words | Get dictionary words with subAttrId list
*BlAmazonApi.ToolApi* | [**getDictionaryWords**](docs/ToolApi.md#getDictionaryWords) | **GET** /tool/dictionary/words | Get dictionary words for filtering within specified browse nodes
*BlAmazonApi.ToolApi* | [**getDictionaryWordsFiltered**](docs/ToolApi.md#getDictionaryWordsFiltered) | **GET** /tool/dictionary/words/{nodeId}/filtered | Get filtered words within a specified browse node with filtering words
*BlAmazonApi.ToolApi* | [**getToolTitles**](docs/ToolApi.md#getToolTitles) | **GET** /tool/titles/{nodeId} | Get 100 amazon best selling item titles within a specified browse node
*BlAmazonApi.ToolApi* | [**postDictionaryProductsAttrs**](docs/ToolApi.md#postDictionaryProductsAttrs) | **POST** /tool/dictionary/products/{nodeId}/attrs | Add attribute within a specified browse node&#39;s
*BlAmazonApi.ToolApi* | [**postDictionaryProductsAttrsSubAttrs**](docs/ToolApi.md#postDictionaryProductsAttrsSubAttrs) | **POST** /tool/dictionary/products/{nodeId}/attrs/{attrId}/subAttrs | Add sub attribute within a specified browse node&#39;s attribute
*BlAmazonApi.ToolApi* | [**postDictionaryWords**](docs/ToolApi.md#postDictionaryWords) | **POST** /tool/dictionary/words | Add filtering word to dictionary


## Documentation for Models

 - [BlAmazonApi.Attr](docs/Attr.md)
 - [BlAmazonApi.BrowseNode](docs/BrowseNode.md)
 - [BlAmazonApi.FeedSubmissionInfo](docs/FeedSubmissionInfo.md)
 - [BlAmazonApi.GetAdvertisingBrowseNodesResponse](docs/GetAdvertisingBrowseNodesResponse.md)
 - [BlAmazonApi.GetAdvertisingBrowseNodesResponseData](docs/GetAdvertisingBrowseNodesResponseData.md)
 - [BlAmazonApi.GetAdvertisingBrowseNodesTopSellersResponse](docs/GetAdvertisingBrowseNodesTopSellersResponse.md)
 - [BlAmazonApi.GetAdvertisingBrowseNodesTopSellersResponseData](docs/GetAdvertisingBrowseNodesTopSellersResponseData.md)
 - [BlAmazonApi.GetAdvertisingStatusResponse](docs/GetAdvertisingStatusResponse.md)
 - [BlAmazonApi.GetDictionaryBrowseNodesAllResponse](docs/GetDictionaryBrowseNodesAllResponse.md)
 - [BlAmazonApi.GetDictionaryBrowseNodesAllResponseData](docs/GetDictionaryBrowseNodesAllResponseData.md)
 - [BlAmazonApi.GetDictionaryBrowseNodesAllResponseSubAttrs](docs/GetDictionaryBrowseNodesAllResponseSubAttrs.md)
 - [BlAmazonApi.GetDictionarySubAttrsWordsResponse](docs/GetDictionarySubAttrsWordsResponse.md)
 - [BlAmazonApi.GetDictionaryWordsFilteredResponse](docs/GetDictionaryWordsFilteredResponse.md)
 - [BlAmazonApi.GetDictionaryWordsFilteredResponseData](docs/GetDictionaryWordsFilteredResponseData.md)
 - [BlAmazonApi.GetDictionaryWordsFilteredResponseDataWords](docs/GetDictionaryWordsFilteredResponseDataWords.md)
 - [BlAmazonApi.GetDictionaryWordsResponse](docs/GetDictionaryWordsResponse.md)
 - [BlAmazonApi.GetDictionaryWordsResponseData](docs/GetDictionaryWordsResponseData.md)
 - [BlAmazonApi.GetMwsFeedsSubmissionsResponse](docs/GetMwsFeedsSubmissionsResponse.md)
 - [BlAmazonApi.GetMwsFeedsSubmissionsResponseData](docs/GetMwsFeedsSubmissionsResponseData.md)
 - [BlAmazonApi.GetMwsFeedsSubmissionsResultResponse](docs/GetMwsFeedsSubmissionsResultResponse.md)
 - [BlAmazonApi.GetMwsFeedsSubmissionsResultResponseData](docs/GetMwsFeedsSubmissionsResultResponseData.md)
 - [BlAmazonApi.GetMwsStatusResponse](docs/GetMwsStatusResponse.md)
 - [BlAmazonApi.GetProductsBrowseNodeAttributesResponse](docs/GetProductsBrowseNodeAttributesResponse.md)
 - [BlAmazonApi.GetProductsBrowseNodeAttributesResponseData](docs/GetProductsBrowseNodeAttributesResponseData.md)
 - [BlAmazonApi.GetProductsBrowseNodeValidValueResponse](docs/GetProductsBrowseNodeValidValueResponse.md)
 - [BlAmazonApi.GetProductsBrowseNodeValidValueResponseData](docs/GetProductsBrowseNodeValidValueResponseData.md)
 - [BlAmazonApi.GetProductsStatusResponse](docs/GetProductsStatusResponse.md)
 - [BlAmazonApi.GetToolTitlesResponse](docs/GetToolTitlesResponse.md)
 - [BlAmazonApi.GetToolTitlesResponseData](docs/GetToolTitlesResponseData.md)
 - [BlAmazonApi.PostDictionaryProductsAttrsResponse](docs/PostDictionaryProductsAttrsResponse.md)
 - [BlAmazonApi.PostDictionaryProductsAttrsSubAttrsResponse](docs/PostDictionaryProductsAttrsSubAttrsResponse.md)
 - [BlAmazonApi.PostDictionaryWordsResponse](docs/PostDictionaryWordsResponse.md)
 - [BlAmazonApi.PostSubmitFeedResponse](docs/PostSubmitFeedResponse.md)
 - [BlAmazonApi.PostSubmitFeedResponseData](docs/PostSubmitFeedResponseData.md)
 - [BlAmazonApi.SubAttr](docs/SubAttr.md)
 - [BlAmazonApi.TitleDic](docs/TitleDic.md)
 - [BlAmazonApi.TopItem](docs/TopItem.md)


## Documentation for Authorization


### api_key

- **Type**: API key
- **API key parameter name**: api_key
- **Location**: HTTP header

